@@ -1,5 +1,5 @@
-use crate::dnsimple::DNSimpleEmptyResponse;
 use crate::dnsimple::registrar::Registrar;
+use crate::dnsimple::DNSimpleEmptyResponse;
 
 impl Registrar<'_> {
     /// Enable domain auto-renewal
@@ -8,7 +8,11 @@ impl Registrar<'_> {
     ///
     /// `account_id`: The account ID
     /// `domain`: The domain name or id
-    pub fn enable_domain_auto_renewal(&self, account_id: u64, domain: String) -> DNSimpleEmptyResponse {
+    pub fn enable_domain_auto_renewal(
+        &self,
+        account_id: u64,
+        domain: String,
+    ) -> DNSimpleEmptyResponse {
         let path = format!("/{}/registrar/domains/{}/auto_renewal", account_id, domain);
 
         self.client.empty_put(&*path)
@@ -20,7 +24,11 @@ impl Registrar<'_> {
     ///
     /// `account_id`: The account ID
     /// `domain`: The domain name or id
-    pub fn disable_domain_auto_renewal(&self, account_id: u64, domain: String) -> DNSimpleEmptyResponse {
+    pub fn disable_domain_auto_renewal(
+        &self,
+        account_id: u64,
+        domain: String,
+    ) -> DNSimpleEmptyResponse {
         let path = format!("/{}/registrar/domains/{}/auto_renewal", account_id, domain);
 
         self.client.delete(&*path)
